stravalib.util.limiter.DefaultRateLimiter
=========================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: DefaultRateLimiter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~DefaultRateLimiter.__init__
